%Code for "Bank Panics, Government Guarantees, and the Long-tun Size of
%   the Financial Sector: Evidence from Free-Banking America" 
%   by B. Chabot and C. Moul

global D1 D2 D3 D4 FB54 SCO54 SCO60
global Dro540 Dro541 Dro542 Dro543 Dro600 Dro601 Dro602 Dro603 Dro607
global Palmer bankdata5

%LOADING DATASETS
load bankdata5;%market-specific info (1644 x 42)
%   sorted by ICPSR state code (NY first) then by town code (last column is ObsID)

load Pops70;%1870/60/50 populations from 1870 Census 
%   sorted by ICPSR state code (NY first) then by town code (last column is ObsID)
% *for 1870, 9.9 indicates not gathered, 10.9 indicates uncertain
% *for 1850, 0 indicates not gathered
bankdata5(:,10)=Pops70(:,2);%replacing 1860 population
bankdata5(:,11)=Pops70(:,3);%replacing 1850 population

%revisions to Weber
load banks1853;%market-number of banks on Dec. 31, 1853
load banks1856;%market-number of banks (actual & IN-corrected) on Dec. 31, 1856
bankdata5=[bankdata5 banks1853 banks1856];%now 1644x45

SampleID=zeros(1644,1);
for i=1:1644;
    SampleID(i)=i;
end;
bankdata5=[bankdata5 SampleID];%now 1644x46

%CONSTRUCTING DISTANCES BETWEEN UNIVERSE OF TOWNS
run JMCBchabotmoul_distmake;%yields DistMat, 1644 x 1644

%CREATING 1854 SAMPLE (denoted D1)
run JMCBchabotmoul_sample1850;%yields D1 (isolated markets in both 1850 & 1860)
sd1=size(D1,1);

%adding revised Panic Eve counts & closures (1854 & 1857)
load bank-counts-and-closures;
BCC=bank_counts_and_closures;
CtPE54=zeros(sd1,1);%Panic Eve 1854 bank count
Clos54=zeros(sd1,1);%closures in 1854 panic
CtPE57=zeros(sd1,1);%Panic Eve 1857 bank count
Clos57=zeros(sd1,1);%closures in 1857 panic
for i=1:sd1;
    f0=find(BCC(:,1)==D1(i,42));
    CtPE54(i)=BCC(f0,2);
    Clos54(i)=BCC(f0,3);
    CtPE57(i)=BCC(f0,4);
    Clos57(i)=BCC(f0,5);
end;

D1=[D1 CtPE54 Clos54 CtPE57 Clos57];%cols 47-50

%adding state-bank & RR info (1854 and 1860)
load state-banks-and-railroads;
SBRR=state_banks_and_railroads;
SB54=zeros(sd1,1);
SB60=zeros(sd1,1);
RR54=zeros(sd1,1);
RR60=zeros(sd1,1);
for i=1:sd1;
    f0=find(SBRR(:,1)==D1(i,42));
    SB54(i)=SBRR(f0,2);
    SB60(i)=SBRR(f0,3);
    RR54(i)=SBRR(f0,4);
    RR60(i)=SBRR(f0,5);
end;

%adding bank-asset info (1854 and 1860)
load asset-level-indicators;
ALI=asset_level_indicators;
AL54=zeros(sd1,1);
AL60=zeros(sd1,1);
for i=1:sd1;
    f0=find(ALI(:,1)==D1(i,42));
    AL54(i)=ALI(f0,2);
    AL60(i)=ALI(f0,3);
end;

D1=[D1 SB54 SB60 RR54 RR60 AL54 AL60];%cols 51:56

%CREATING 1860 SAMPLE (denoted D2)
run JMCBchabotmoul_sample1860;%yields D2 (isolated markets in 1860)
sd2=size(D2,1);

%adding revised Panic Eve counts & closures (1854 & 1857)
load bank-counts-and-closures;
BCC=bank_counts_and_closures;
CtPE54=zeros(sd2,1);
Clos54=zeros(sd2,1);
CtPE57=zeros(sd2,1);
Clos57=zeros(sd2,1);
for i=1:sd2;
    f0=find(BCC(:,1)==D2(i,42));
    CtPE54(i)=BCC(f0,2);
    Clos54(i)=BCC(f0,3);
    CtPE57(i)=BCC(f0,4);
    Clos57(i)=BCC(f0,5);
end;

D2=[D2 CtPE54 Clos54 CtPE57 Clos57];%cols 47-50

%agregate closure rate from '54 and '57 panics 
Ct=CtPE54+CtPE57;
Clos=Clos54+Clos57;
CR=zeros(sd2,1);
for i=1:sd2;
    if Ct(i)>0;
        CR(i)=Clos(i)/Ct(i);
    end;
end;

D2=[D2 [Ct>0] CR];%cols 51-52 

%adding state-bank & RR info (1854 and 1860)
load state-banks-and-railroads;
SBRR=state_banks_and_railroads;
SB54=zeros(sd2,1);
SB60=zeros(sd2,1);
RR54=zeros(sd2,1);
RR60=zeros(sd2,1);
for i=1:sd2;
    f0=find(SBRR(:,1)==D2(i,42));
    SB54(i)=SBRR(f0,2);
    SB60(i)=SBRR(f0,3);
    RR54(i)=SBRR(f0,4);
    RR60(i)=SBRR(f0,5);
end;

%adding bank-asset info (1854 and 1860)
load asset-level-indicators;
ALI=asset_level_indicators;
AL54=zeros(sd2,1);
AL60=zeros(sd2,1);
for i=1:sd1;
    f0=find(ALI(:,1)==D2(i,42));
    AL54(i)=ALI(f0,2);
    AL60(i)=ALI(f0,3);
end;

D2=[D2 SB54 SB60 RR54 RR60 AL54 AL60];%cols 53:58
sd2=size(D2,1);

%ELIMINATING OBSERVATIONS FROM SAMPLE
%dropping Iowa from 1854 sample (banking illegal until 1858)
f=find(D1(:,23)==0);%identifies non-Iowa states
D1=D1(f,:);
sd1=size(D1,1);

%dropping MO & PA from 1854 sample (non-free banking states)
%f=find(D1(:,17)+D1(:,24)==0);%identifies non-PA/MO states
%D1=D1(f,:);
%sd1=size(D1,1);

%creating year-specific free-banking indicators
FB54=zeros(sd1,1);
for i=1:sd1;
    FB54(i)=sum(D1(i,18:22));
end;
SCO54=1-FB54;%state-charter-only 

FB60=zeros(sd2,1);
for i=1:sd2;
    FB60(i)=sum(D2(i,17:23));
end;
%counting PA '60 as SCO
FB60=FB60-D2(:,17);%PA adopted free-banking late in 1860
%counting IA '60 as SCO
%FB60=FB60-D(:,23);
SCO60=1-FB60;

%CONSTRUCTING DROUGHT VARIABLES
%1854 sample
load palmer;%loading gridpoints of reconstructed Palmer Drought Severity Index
d1=[D1(:,14) D1(:,15)];%latitude and longitude

Dr1=JMCBchabotmoul_makedrought1(d1);%N x 61 (mkts by 1800-'60 PDSI)

yr=54+1;%either 53 or 56

szDr1=size(Dr1,1);
lookback=5;
wts1=zeros(lookback,1);
for j=1:lookback;
    wts1(j)=j/lookback;
end;

Dro540=zeros(szDr1,1);%for 1853/56 cross-section
Dro541=zeros(szDr1,1);%for 1853/56 cross-section
Dro542=zeros(szDr1,1);%for 1853/56 cross-section
Dro543=zeros(szDr1,1);%for 1853/56 cross-section
for i=1:szDr1;
    Dro540(i)=-Dr1(i,yr+1-lookback:yr)*wts1;%straight sum
    Dro541(i)=((Dr1(i,yr+1-lookback:yr).*[Dr1(i,yr+1-lookback:yr)<0]).^2)*wts1;%squared
    Dro542(i)=[Dr1(i,yr+1-lookback:yr)<-2]*wts1;%straight sum
end;
Dro543=[Dr1(:,57)<-2];

%1860 sample
load palmer;%loading gridpoints of reconstructed Palmer Drought Severity Index
d2=[D2(:,14) D2(:,15)];%latitude and longitude

Dr2=JMCBchabotmoul_makedrought1(d2);%N x 61 (mkts by 1800-'60 PDSI)

szDr2=size(Dr2,1);
LB=5;%lookback
wts1=zeros(LB,1);
for j=1:LB;
    wts1(j)=j/LB;
end;

Dro600=zeros(szDr2,1);%for 1860 cross-section
Dro601=zeros(szDr2,1);%for 1860 cross-section
Dro602=zeros(szDr2,1);%for 1860 cross-section
Dro603=zeros(szDr2,1);%for 1860 cross-section
for i=1:szDr2;
    Dro600(i)=-Dr2(i,62-LB:61)*wts1;%straight sum
    Dro601(i)=((Dr2(i,62-LB:61).*[Dr2(i,62-LB:61)<0]).^2)*wts1;%squared
    Dro602(i)=[Dr2(i,62-LB:61)<-2]*wts1;%straight sum
end;
Dro603=[Dr2(:,57)<-2];


%DEFINING VARIABLES FOR 1854 SAMPLE
%Population
Pop50=D1(:,11)/1000;%aggregate population in 1850
Pop60=D1(:,10)/1000;%aggregate population in 1860
Pop54a=Pop50.*((Pop60./Pop50).^(.4));%geometric weighted average
Pop54b=Pop50+(Pop60-Pop50)*(.4);%arithmetic weighted average
Pop56a=Pop50.*((Pop60./Pop50).^(.6));%geometric weighted average
Pop56b=Pop50+(Pop60-Pop50)*(.6);%arithmetic weighted average
Pop54=Pop54b;

%dropping St. Louis & Cincinnati (potentially isolated but too large)
f=find(Pop60<50);%drops St. Louis & Cincinnati
D1=D1(f,:);
sd1=size(D1,1);


IN1=D1(:,20);%Indiana dummy
RR54=D1(:,53);%Railroad dummy in '54

%Geographic coordinates
Lat=D1(:,14)/1000000;%latitude
Long=-D1(:,15)/1000000;%longitude

%Number of banks in market
N53=D1(:,43);%number of banks in December 1853
N54=D1(:,47);%number of banks in August 1854
%N56=D1(:,44);%number of banks in 1856 (does not correct for IN-state charter screw-up)
N56=D1(:,45);%number of banks in 1856 (does  correct for IN-state charter screw-up)
N57=D1(:,49);%number of banks in September 1857

%Bank closures
%number of panic-year closings in market (1854 & '57)
Clos54=D1(:,48);
Clos57=D1(:,50);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SUMMARY STATS FOR 1854 SAMPLE %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

SS5401=[sum([IN1==1]) sum([IN1==0].*[SCO54==0]) sum([IN1==0].*[SCO54==1])];
SS5402=[sum([IN1==1].*[N54==0]) sum([IN1==0].*[SCO54==0].*[N54==0]) sum([IN1==0].*[SCO54==1].*[N54==0])];
SS5403=[sum([IN1==1].*[N54==1]) sum([IN1==0].*[SCO54==0].*[N54==1]) sum([IN1==0].*[SCO54==1].*[N54==1])];
SS5404=[sum([IN1==1].*[N54==2]) sum([IN1==0].*[SCO54==0].*[N54==2]) sum([IN1==0].*[SCO54==1].*[N54==2])];
SS5405=[sum([IN1==1].*[N54>2]) sum([IN1==0].*[SCO54==0].*[N54>2]) sum([IN1==0].*[SCO54==1].*[N54>2])];
SS5406=[sum([IN1==1].*Pop54)/sum([IN1==1]) sum([IN1==0].*[SCO54==0].*Pop54)/sum([IN1==0].*[SCO54==0]) ...
    sum([IN1==0].*[SCO54==1].*Pop54)/sum([IN1==0].*[SCO54==1])];
SS5407=[sum([IN1==1].*[N54==0].*Pop54)/sum([IN1==1].*[N54==0]) ...
    sum([IN1==0].*[SCO54==0].*[N54==0].*Pop54)/sum([IN1==0].*[SCO54==0].*[N54==0]) ...
    sum([IN1==0].*[SCO54==1].*[N54==0].*Pop54)/sum([IN1==0].*[SCO54==1].*[N54==0])];
SS5408=[sum([IN1==1].*[N54==1].*Pop54)/sum([IN1==1].*[N54==1]) ...
    sum([IN1==0].*[SCO54==0].*[N54==1].*Pop54)/sum([IN1==0].*[SCO54==0].*[N54==1]) ...
    sum([IN1==0].*[SCO54==1].*[N54==1].*Pop54)/sum([IN1==0].*[SCO54==1].*[N54==1])];
SS5409=[sum([IN1==1].*[N54==2].*Pop54)/sum([IN1==1].*[N54==2]) ...
    sum([IN1==0].*[SCO54==0].*[N54==2].*Pop54)/sum([IN1==0].*[SCO54==0].*[N54==2]) ...
    sum([IN1==0].*[SCO54==1].*[N54==2].*Pop54)/sum([IN1==0].*[SCO54==1].*[N54==2])];
SS5410=[sum([IN1==1].*[N54>2].*Pop54)/sum([IN1==1].*[N54>2]) ...
    sum([IN1==0].*[SCO54==0].*[N54>2].*Pop54)/sum([IN1==0].*[SCO54==0].*[N54>2]) ...
    sum([IN1==0].*[SCO54==1].*[N54>2].*Pop54)/sum([IN1==0].*[SCO54==1].*[N54>2])];
SS5411=[sum([IN1==1].*Dro541)/sum(IN1==1) sum([IN1==0].*[SCO54==0].*Dro541)/sum([IN1==0].*[SCO54==0]) ...
    sum([IN1==0].*[SCO54==1].*Dro541)/sum([IN1==0].*[SCO54==1])];
SS5412=[sum([IN1==1].*(Dro541.*Pop54))/sum([IN1==1]) ...
    sum([IN1==0].*[SCO54==0].*(Dro541.*Pop54))/sum([IN1==0].*[SCO54==0]) ...
    sum([IN1==0].*[SCO54==1].*(Dro541.*Pop54))/sum([IN1==0].*[SCO54==1])];
SS5413=[sum([IN1==1].*[RR54==1])/sum([IN1==1]) sum([IN1==0].*[SCO54==0].*[RR54==1])/sum([IN1==0].*[SCO54==0]) ...
    sum([IN1==0].*[SCO54==1].*[RR54==1])/sum([IN1==0].*[SCO54==1])];

SumStat54=[SS5401;SS5402;SS5403;SS5404;SS5405;SS5406;SS5407;;SS5408;SS5409;SS5410;SS5411;SS5412;SS5413];
disp('Summary statistics for August 1854: Table 4A')
disp(SumStat54)


%DEFINING VARIABLES FOR 1860 SAMPLE
%Population
Pop60=D2(:,10)/1000;%aggregate population in 1860
IN2=D2(:,20);

%dropping St. Louis & Cincinnati (potentially isolated but too large)
f=find(Pop60<50);%drops St. Louis
D2=D2(f,:);

%Geographic coordinates
Lat=D2(:,14)/1000000;
Long=-D2(:,15)/1000000;

%Number of banks in market
N54=D2(:,47);%number of banks in August 1854
%N56=D2(:,44);%number of banks in 1856 (does *not* correct for IN-state charter screw-up)
N56=D2(:,45);%number of banks in 1856 (*does* correct for IN-state charter screw-up)
N57=D2(:,49);%number of banks in September 1857
N60=D2(:,26);%number of banks in 1860

%Bank closures
AllClos=sum(D2(:,33:41),2);%number of all bank closings in market (1851-59)
NPClos=D2(:,33)+D2(:,34)+D2(:,35)+D2(:,37)+D2(:,38)+D2(:,40)+D2(:,41);
%number of non-panic-year closings in market (1851-59 w/o '54 & '57)
PClos=D2(:,36)+D2(:,39);
%number of panic-year closings in market (1854 & '57)
Clos54=D2(:,48);
Clos57=D2(:,50);

int=ones(sd2,1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SUMMARY STATS FOR 1860 SAMPLE %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

SS6001=[sum([IN2==1]) sum([IN2==0].*[SCO60==0]) sum([IN2==0].*[SCO60==1])];
SS6002=[sum([IN2==1].*[N60==0]) sum([IN2==0].*[SCO60==0].*[N60==0]) sum([IN2==0].*[SCO60==1].*[N60==0])];
SS6003=[sum([IN2==1].*[N60==1]) sum([IN2==0].*[SCO60==0].*[N60==1]) sum([IN2==0].*[SCO60==1].*[N60==1])];
SS6004=[sum([IN2==1].*[N60==2]) sum([IN2==0].*[SCO60==0].*[N60==2]) sum([IN2==0].*[SCO60==1].*[N60==2])];
SS6005=[sum([IN2==1].*[N60>2]) sum([IN2==0].*[SCO60==0].*[N60>2]) sum([IN2==0].*[SCO60==1].*[N60>2])];
SS6006=[sum([IN2==1].*Pop60)/sum([IN2==1]) sum([IN2==0].*[SCO60==0].*Pop60)/sum([IN2==0].*[SCO60==0]) ...
    sum([IN2==0].*[SCO60==1].*Pop60)/sum([IN2==0].*[SCO60==1])];
SS6007=[sum([IN2==1].*[N60==0].*Pop60)/sum([IN2==1].*[N60==0]) ...
    sum([IN2==0].*[SCO60==0].*[N60==0].*Pop60)/sum([IN2==0].*[SCO60==0].*[N60==0]) ...
    sum([IN2==0].*[SCO60==1].*[N60==0].*Pop60)/sum([IN2==0].*[SCO60==1].*[N60==0])];
SS6008=[sum([IN2==1].*[N60==1].*Pop60)/sum([IN2==1].*[N60==1]) ...
    sum([IN2==0].*[SCO60==0].*[N60==1].*Pop60)/sum([IN2==0].*[SCO60==0].*[N60==1]) ...
    sum([IN2==0].*[SCO60==1].*[N60==1].*Pop60)/sum([IN2==0].*[SCO60==1].*[N60==1])];
SS6009=[sum([IN2==1].*[N60==2].*Pop60)/sum([IN2==1].*[N60==2]) ...
    sum([IN2==0].*[SCO60==0].*[N60==2].*Pop60)/sum([IN2==0].*[SCO60==0].*[N60==2]) ...
    sum([IN2==0].*[SCO60==1].*[N60==2].*Pop60)/sum([IN2==0].*[SCO60==1].*[N60==2])];
SS6010=[sum([IN2==1].*[N60>2].*Pop60)/sum([IN2==1].*[N60>2]) ...
    sum([IN2==0].*[SCO60==0].*[N60>2].*Pop60)/sum([IN2==0].*[SCO60==0].*[N60>2]) ...
    sum([IN2==0].*[SCO60==1].*[N60>2].*Pop60)/sum([IN2==0].*[SCO60==1].*[N60>2])];
SS6011=[sum([IN2==1].*Dro601)/sum(IN2==1) sum([IN2==0].*[SCO60==0].*Dro601)/sum([IN2==0].*[SCO60==0]) ...
    sum([IN2==0].*[SCO60==1].*Dro601)/sum([IN2==0].*[SCO60==1])];
SS6012=[sum([IN2==1].*(Dro601.*Pop60))/sum([IN2==1]) ...
    sum([IN2==0].*[SCO60==0].*(Dro601.*Pop60))/sum([IN2==0].*[SCO60==0]) ...
    sum([IN2==0].*[SCO60==1].*(Dro601.*Pop60))/sum([IN2==0].*[SCO60==1])];
SS6013=[sum([IN2==1].*[RR60==1])/sum([IN2==1]) sum([IN2==0].*[SCO60==0].*[RR60==1])/sum([IN2==0].*[SCO60==0]) ...
    sum([IN2==0].*[SCO60==1].*[RR60==1])/sum([IN2==0].*[SCO60==1])];
SS6014=[sum([IN2==1].*N54)/sum([IN2==1]) sum([IN2==0].*[SCO60==0].*N54)/sum([IN2==0].*[SCO60==0]) ...
    sum([IN2==0].*[SCO60==1].*N54)/sum([IN2==0].*[SCO60==1])];
SS6015=[sum([IN2==1].*Clos54)/sum([IN2==1]) sum([IN2==0].*[SCO60==0].*Clos54)/sum([IN2==0].*[SCO60==0]) ...
    sum([IN2==0].*[SCO60==1].*Clos54)/sum([IN2==0].*[SCO60==1])];
SS6016=[sum([IN2==1].*N57)/sum([IN2==1]) sum([IN2==0].*[SCO60==0].*N57)/sum([IN2==0].*[SCO60==0]) ...
    sum([IN2==0].*[SCO60==1].*N57)/sum([IN2==0].*[SCO60==1])];
SS6017=[sum([IN2==1].*Clos57)/sum([IN2==1]) sum([IN2==0].*[SCO60==0].*Clos57)/sum([IN2==0].*[SCO60==0]) ...
    sum([IN2==0].*[SCO60==1].*Clos57)/sum([IN2==0].*[SCO60==1])];

SumStat60=[SS6001;SS6002;SS6003;SS6004;SS6005;SS6006;SS6007;;SS6008;SS6009;SS6010;SS6011;SS6012;SS6013;...
    SS6014;SS6015;SS6016;SS6017];
disp('Summary statistics for December 1860: Table 4B')
disp(SumStat60)
disp('Note: Multiply populations by 1000 to match Table 4')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  SEPARATE CROSS-SECTIONS, 1854 & 1860: TABLE 5  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% MAXIMUM LIKELIHOOD ON 1854 SAMPLE: TABLE 5A & 5B %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%
% DUOPOLY-PLUS: TABLE 5A %
%%%%%%%%%%%%%%%%%%%%%%%%%%

%opening guess at parameters
g5a0=[7.308;.408;.832;-2.453;.726;1.014;-.981;-.184];

options=optimset('MaxFunEvals',100000,'MaxIter',100000);

g5a=fminsearch('JMCBchabotmoul5a',g5a0,options);%no-bank, monopoly-bank, duopoly-plus
L05a=JMCBchabotmoul5a(g5a);%obj func value at optimal parameters
L0=L05a;

%CONSTRUCTING INFORMATION MATRIX 
h0=g5a;
sg5a=size(g5a,1);
Info=zeros(sg5a,sg5a);
for i=1:sg5a;
    for j=1:sg5a;
        h1=h0;
        h2=h0;
        ep=.00001;
        h1(i)=h0(i)+ep;
        h2(j)=h0(j)+ep;
        h3=h2;
        h3(i)=h2(i)+ep;
        L1=JMCBchabotmoul5a(h1);
        L2=JMCBchabotmoul5a(h2);
        L3=JMCBchabotmoul5a(h3);
        Info(i,j)=((L3-L2)/ep-(L1-L0)/ep)/ep;
    end;
end;

%CONSTRUCTING COVARIANCE MATRIX
V5a=inv(Info);
se5a=sqrt(diag(V5a));

disp('1854 cross section with Duopoly-Plus: Table 5a')
disp('   Estimate     s.e.')
disp([g5a se5a])
disp('/log-lik/')
disp(L05a)

%CONSTRUCTING ENTRY THRESHOLDS & STD ERRORS (delta method)
%monopoly, IN=0 & SCO=0
w1=(g5a(1))/g5a(3);
W1=exp(w1);
h1=[(1/g5a(3))*W1;0;-w1*(1/g5a(3))*W1;zeros(5,1)];
sw1=sqrt(h1'*V5a*h1);

%monopoly, IN=0 & SCO=1
w2=(g5a(1)-g5a(7))/g5a(3);
W2=exp(w2);
h2=[(1/g5a(3))*W2;0;-w2*(1/g5a(3))*W2;zeros(3,1);-(1/g5a(3))*W2;0];
sw2=sqrt(h2'*V5a*h2);

%monopoly, IN=1
w3=(g5a(1)-g5a(6))/g5a(3);
W3=exp(w3);
h3=[(1/g5a(3))*W3;0;-w3*(1/g5a(3))*W3;zeros(2,1);-(1/g5a(3))*W3;0;0];
sw3=sqrt(h3'*V5a*h3);

%duopoly, IN=0 & SCO=0
w5=(g5a(1)+(g5a(2)+log(2)))/g5a(3);
W5=exp(w5);
h5=[(1/g5a(3))*W5;(1/g5a(3))*W5;-w5*(1/g5a(3))*W5;zeros(5,1)];
sw5=sqrt(h5'*V5a*h5);

%duopoly, IN=0 & SCO=1 (not shown b/c SCO duopoly so rare in 1854)
w6=(g5a(1)+(g5a(2)+log(2))-g5a(7))/g5a(3);
W6=exp(w6);
h6=[(1/g5a(3))*W6;(1/g5a(3))*W6;-w6*(1/g5a(3))*W6;zeros(3,1);-(1/g5a(3))*W6;0];
sw6=sqrt(h6'*V5a*h6);

%duopoly, IN=1
w7=(g5a(1)+(g5a(2)+log(2))-g5a(6))/g5a(3);
W7=exp(w7);
h7=[(1/g5a(3))*W7;(1/g5a(3))*W7;-w7*(1/g5a(3))*W7;zeros(2,1);-(1/g5a(3))*W7;0;0];
sw7=sqrt(h7'*V5a*h7);

W5a=[W1;W2;W3;W5;W7];
sw5a=[sw1;sw2;sw3;sw5;sw7];

disp('Implied entry thresholds for 1854 Duopoly-Plus: Table 5a')
disp('   Estimate     s.e.')
disp([W5a sw5a])

%CONSTRUCTING THRESHOLD RATIOS & STD ERRORS
z15a=(g5a(2)+log(2))/g5a(3);
Z15a=exp(z15a);
k15a=[0;(1/g5a(3))*Z15a;-z15a*(1/g5a(3))*Z15a;zeros(5,1)];
sk15a=sqrt(k15a'*V5a*k15a);

Z25a=.5*Z15a;
sk25a=.5*sk15a;
p25a=2*(1-normcdf((Z25a-1)/sk25a));

disp('Duopoly-vs-Monopoly threshold test (Per-firm pop ratio)')
disp('    Ratio     s.e.      p-value')
disp([Z25a sk25a p25a])

%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TRIOPOLY-PLUS: TABLE 5B %
%%%%%%%%%%%%%%%%%%%%%%%%%%%

%opening guess at parameters
g05b=[9.771;.381;.927;1.168;-1.629;.256;1.065;-.926;-.165];

g5b=fminsearch('JMCBchabotmoul5b',g05b,options);%no-bank, monopoly-bank, duopoly, triopoly-plus

L05b=JMCBchabotmoul5b(g5b);%obj func value at optimal parameters
L0=L05b;

%CONSTRUCTING INFORMATION MATRIX
h0=g5b;
sg5b=size(g5b,1);
Info=zeros(sg5b,sg5b);
for i=1:sg5b;
    for j=1:sg5b;
        h1=h0;
        h2=h0;
        ep=.00001;
        h1(i)=h0(i)+ep;
        h2(j)=h0(j)+ep;
        h3=h2;
        h3(i)=h2(i)+ep;
        L1=JMCBchabotmoul5b(h1);
        L2=JMCBchabotmoul5b(h2);
        L3=JMCBchabotmoul5b(h3);
        Info(i,j)=((L3-L2)/ep-(L1-L0)/ep)/ep;
    end;
end;

%CONSTRUCTING COVARIANCE MATRIX
V5b=inv(Info);
se5b=sqrt(diag(V5b));

disp('1854 cross section with Triopoly-Plus: Table 5b')
disp('   Estimate     s.e.')
disp([g5b se5b])
disp('/log-lik/')
disp(L05b)

%TESTING NULL THAT MU_DUO = MU_TRI
k5b=[0;-1;1;zeros(6,1)];
J5b=(k5b'*g5b)/sqrt(k5b'*V5b*k5b);
p5b=2*(1-normcdf(J5b));
disp('p-stat on mu_duo=mu_tri')
disp(p5b)

%CONSTRUCTING ENTRY THRESHOLDS & STD ERRORS (delta method)

%monopoly, IN=0 & SCO=0
w1=(g5b(1))/g5b(4);
W1=exp(w1);
h1=[(1/g5b(4))*W1;0;0;-w1*(1/g5b(4))*W1;zeros(5,1)];
sw1=sqrt(h1'*V5b*h1);

%monopoly, IN=0 & SCO=1
w2=(g5b(1)-g5b(8))/g5b(4);
W2=exp(w2);
h2=[(1/g5b(4))*W2;0;0;-w2*(1/g5b(4))*W2;zeros(3,1);-(1/g5b(4))*W2;0];
sw2=sqrt(h2'*V5b*h2);

%monopoly, IN=1
w3=(g5b(1)-g5b(7))/g5b(4);
W3=exp(w3);
h3=[(1/g5b(4))*W3;0;0;-w3*(1/g5b(4))*W3;zeros(2,1);-(1/g5b(4))*W3;0;0];
sw3=sqrt(h3'*V5b*h3);

%duopoly, IN=0 & SCO=0
w5=(g5b(1)+(g5b(2)+log(2)))/g5b(4);
W5=exp(w5);
h5=[(1/g5b(4))*W5;(1/g5b(4))*W5;0;-w5*(1/g5b(4))*W5;zeros(5,1)];
sw5=sqrt(h5'*V5b*h5);

%duopoly, IN=0 & SCO=1 (not shown b/c SCO duopoly so rare in 1854)
w6=(g5b(1)+(g5b(2)+log(2))-g5b(8))/g5b(4);
W6=exp(w6);
h6=[(1/g5b(4))*W6;(1/g5b(4))*W6;0;-w6*(1/g5b(4))*W6;zeros(3,1);-(1/g5b(4))*W6;0];
sw6=sqrt(h6'*V5b*h6);

%duopoly, IN=1
w7=(g5b(1)+(g5b(2)+log(2))-g5b(7))/g5b(4);
W7=exp(w7);
h7=[(1/g5b(4))*W7;(1/g5b(4))*W7;0;-w7*(1/g5b(4))*W7;zeros(2,1);-(1/g5b(4))*W7;0;0];
sw7=sqrt(h7'*V5b*h7);

%triopoly, IN=0 & SCO=0
w9=(g5b(1)+(g5b(3)+log(3)))/g5b(4);
W9=exp(w9);
h9=[(1/g5b(4))*W9;0;(1/g5b(4))*W9;-w9*(1/g5b(4))*W9;zeros(5,1)];
sw9=sqrt(h9'*V5b*h9);

%triopoly, IN=0 & SCO=1 (not shown b/c SCO triopoly non-existent in 1854)
w10=(g5b(1)+(g5b(3)+log(3))-g5b(8))/g5b(4);
W10=exp(w10);
h10=[(1/g5b(4))*W10;0;(1/g5b(4))*W10;-w10*(1/g5b(4))*W10;zeros(3,1);-(1/g5b(4))*W10;0];
sw10=sqrt(h10'*V5b*h10);

%triopoly, IN=1
w11=(g5b(1)+(g5b(3)+log(3))-g5b(7))/g5b(4);
W11=exp(w11);
h11=[(1/g5b(4))*W11;0;(1/g5b(4))*W11;-w11*(1/g5b(4))*W11;zeros(2,1);-(1/g5b(4))*W11;0;0];
sw11=sqrt(h11'*V5b*h11);

W5b=[W1;W2;W3;W5;W7;W9;W11];
sw5b=[sw1;sw2;sw3;sw5;sw7;sw9;sw11];

disp('Implied entry thresholds for 1854 Triopoly-Plus: Table 5b')
disp('   Estimate     s.e.')
disp([W5b sw5b])


%CONSTRUCTING THRESHOLD RATIOS & STD ERRORS
z15b=(g5b(2)+log(2))/g5b(4);
Z15b=exp(z15b);
k15b=[0;(1/g5b(4))*Z15b;0;-z15b*(1/g5b(4))*Z15b;zeros(5,1)];
sk15b=sqrt(k15b'*V5b*k15b);

Z25b=.5*Z15b;
sk25b=.5*sk15b;
p25b=2*(1-normcdf((Z25b-1)/sk25b));

z35b=(g5b(3)+log(3)-g5b(2)-log(2))/g5b(4);
Z35b=exp(z35b);
k35b=[0;-(1/g5b(4))*Z35b;(1/g5b(4))*Z35b;-z35b*(1/g5b(4))*Z35b;zeros(5,1)];
sk35b=sqrt(k35b'*V5b*k35b);

Z45b=(2/3)*Z35b;
sk45b=(2/3)*sk35b;
p45b=2*(1-normcdf((Z45b-1)/sk45b));

disp('Duopoly-vs-Monopoly threshold test (Per-firm pop ratio)')
disp('    Ratio     s.e.      p-value')
disp([Z25b sk25b p25b])
disp('Triopoly-vs-Duopoly threshold test (Per-firm pop ratio)')
disp('    Ratio     s.e.      p-value')
disp([Z45b sk45b p45b])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% MAXIMUM LIKELIHOOD ON 1860 SAMPLE: TABLE 5C & 5D %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%
% DUOPOLY-PLUS: TABLE 5C %
%%%%%%%%%%%%%%%%%%%%%%%%%%

%opening guess at parameters
g05c=[5.189;.315;.641;-.151;.017;-.488;-.291;-.501];

g5c=fminsearch('JMCBchabotmoul5c',g05c);%no-bank, monopoly-bank, duopoly-plus

L05c=JMCBchabotmoul5c(g5c);%obj func value at optimal parameters
L0=L05c;

%CONSTRUCTING INFORMATION MATRIX
h0=g5c;
sg5c=size(g5c,1);
Info=zeros(sg5c,sg5c);
for i=1:sg5c;
    for j=1:sg5c;
        h1=h0;
        h2=h0;
        ep=.00001;
        h1(i)=h0(i)+ep;
        h2(j)=h0(j)+ep;
        h3=h2;
        h3(i)=h2(i)+ep;
        L1=JMCBchabotmoul5c(h1);
        L2=JMCBchabotmoul5c(h2);
        L3=JMCBchabotmoul5c(h3);
        Info(i,j)=((L3-L2)/ep-(L1-L0)/ep)/ep;
    end;
end;

%CONSTRUCTING COVARIANCE MATRIX
V5c=inv(Info);
se5c=sqrt(diag(V5c));

disp('1860 cross section with Duopoly-Plus: Table 5c')
disp('   Estimate     s.e.')
disp([g5c se5c])
disp('/log-lik/')
disp(L05c)

%CONSTRUCTING ENTRY THRESHOLDS & STD ERRORS (delta method)

%monopoly, IN=0 & SCO=0
w1=(g5c(1))/g5c(3);
W1=exp(w1);
h1=[(1/g5c(3))*W1;0;-w1*(1/g5c(3))*W1;zeros(5,1)];
sw1=sqrt(h1'*V5c*h1);

%monopoly, IN=0 & SCO=1
w2=(g5c(1)-g5c(7))/g5c(3);
W2=exp(w2);
h2=[(1/g5c(3))*W2;0;-w2*(1/g5c(3))*W2;zeros(3,1);-(1/g5c(3))*W2;0];
sw2=sqrt(h2'*V5c*h2);

%monopoly, IN=1
w3=(g5c(1)-g5c(6))/g5c(3);
W3=exp(w3);
h3=[(1/g5c(3))*W3;0;-w3*(1/g5c(3))*W3;zeros(2,1);-(1/g5c(3))*W3;0;;0];
sw3=sqrt(h3'*V5c*h3);

%duopoly, IN=0 & SCO=0
w5=(g5c(1)+(g5c(2)+log(2)))/g5c(3);
W5=exp(w5);
h5=[(1/g5c(3))*W5;(1/g5c(3))*W5;-w5*(1/g5c(3))*W5;zeros(5,1)];
sw5=sqrt(h5'*V5c*h5);

%duopoly, IN=0 & SCO=1 (not shown b/c SCO duopoly still uncommon in 1860)
w6=(g5c(1)+(g5c(2)+log(2))-g5c(7))/g5c(3);
W6=exp(w6);
h6=[(1/g5c(3))*W6;(1/g5c(3))*W6;-w6*(1/g5c(3))*W6;zeros(3,1);-(1/g5c(3))*W6;0];
sw6=sqrt(h6'*V5c*h6);

%duopoly, IN=1
w7=(g5c(1)+(g5c(2)+log(2))-g5c(6))/g5c(3);
W7=exp(w7);
h7=[(1/g5c(3))*W7;(1/g5c(3))*W7;-w7*(1/g5c(3))*W7;zeros(2,1);-(1/g5c(3))*W7;0;0];
sw7=sqrt(h7'*V5c*h7);

W5c=[W1;W2;W3;W5;W7];
sw5c=[sw1;sw2;sw3;sw5;sw7];

disp('Implied entry thresholds for 1860 Duopoly-Plus: Table 5c')
disp('   Estimate     s.e.')
disp([W5c sw5c])

%CONSTRUCTING THRESHOLD RATIOS & STD ERRORS
z15c=(g5c(2)+log(2))/g5c(3);
Z15c=exp(z15c);
k15c=[0;(1/g5c(3))*Z15c;-z15c*(1/g5c(3))*Z15c;zeros(5,1)];
sk15c=sqrt(k15c'*V5c*k15c);

Z25c=.5*Z15c;
sk25c=.5*sk15c;
pk25c=2*(1-normcdf((Z25c-1)/sk25c));

disp('Duopoly-vs-Monopoly threshold test (Per-firm pop ratio)')
disp('    Ratio     s.e.      p-value')
disp([Z25c sk25c pk25c])
%Note: Footnote 49 mis-states p-value for this duopoly-vs-monopoly hypothesis-test, 
%  specifically tests null of zero instead of correct null of one ... correct 
%  p-value under duopoly-plus is p = 0.15

%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TRIOPOLY-PLUS: TABLE 5D %
%%%%%%%%%%%%%%%%%%%%%%%%%%%

%opening guess at parameters
g05d=[5.176;.316;.543;.639;-.145;.012;-.470;-.286;-.527];

options=optimset('MaxFunEvals',100000,'MaxIter',100000);

g5d=fminsearch('JMCBchabotmoul5d',g05d,options);%no-bank, monopoly-bank, duopoly, triopoly-plu

L05d=JMCBchabotmoul5d(g5d);%obj func value at optimal parameters
L0=L05d;

%CONSTRUCTING INFORMATION MATRIX
h0=g5d;
sg5d=size(g5d,1);
Info=zeros(sg5d,sg5d);
for i=1:sg5d;
    for j=1:sg5d;
        h1=h0;
        h2=h0;
        ep=.00001;
        h1(i)=h0(i)+ep;
        h2(j)=h0(j)+ep;
        h3=h2;
        h3(i)=h2(i)+ep;
        L1=JMCBchabotmoul5d(h1);
        L2=JMCBchabotmoul5d(h2);
        L3=JMCBchabotmoul5d(h3);
        Info(i,j)=((L3-L2)/ep-(L1-L0)/ep)/ep;
    end;
end;

%CONSTRUCTING COVARIANCE MATRIX
V5d=inv(Info);
se5d=sqrt(diag(V5d));

disp('1860 cross section with Triopoly-Plus: Table 5d')
disp('   Estimate     s.e.')
disp([g5d se5d])
disp('/log-lik/')
disp(L05d)

%TESTING NULL THAT MU_DUO = MU_TRI
k5d=[0;-1;1;zeros(6,1)];
J5d=(k5d'*g5d)/sqrt(k5d'*V5d*k5d);
p5d=2*(1-normcdf(J5d));
disp('p-stat on mu_duo=mu_tri')
disp(p5d)

%CONSTRUCTING ENTRY THRESHOLDS & STD ERRORS (delta method)

%monopoly, IN=0 & SCO=0
w1=(g5d(1))/g5d(4);
W1=exp(w1);
h1=[(1/g5d(4))*W1;0;0;-w1*(1/g5d(4))*W1;zeros(5,1)];
sw1=sqrt(h1'*V5d*h1);

%monopoly, IN=0 & SCO=1
w2=(g5d(1)-g5d(8))/g5d(4);
W2=exp(w2);
h2=[(1/g5d(4))*W2;0;0;-w2*(1/g5d(4))*W2;zeros(3,1);-(1/g5d(4))*W2;0];
sw2=sqrt(h2'*V5d*h2);

%monopoly, IN=1
w3=(g5d(1)-g5d(7))/g5d(4);
W3=exp(w3);
h3=[(1/g5d(4))*W3;0;0;-w3*(1/g5d(4))*W3;zeros(2,1);-(1/g5d(4))*W3;0;0];
sw3=sqrt(h3'*V5d*h3);

%duopoly, IN=0 & SCO=0
w5=(g5d(1)+(g5d(2)+log(2)))/g5d(4);
W5=exp(w5);
h5=[(1/g5d(4))*W5;(1/g5d(4))*W5;0;-w5*(1/g5d(4))*W5;zeros(5,1)];
sw5=sqrt(h5'*V5d*h5);

%duopoly, IN=0 & SCO=1 (not shown b/c SCO duopoly still uncommon in 1860)
w6=(g5d(1)+(g5d(2)+log(2))-g5d(8))/g5d(4);
W6=exp(w6);
h6=[(1/g5d(4))*W6;(1/g5d(4))*W6;0;-w6*(1/g5d(4))*W6;zeros(3,1);-(1/g5d(4))*W6;0];
sw6=sqrt(h6'*V5d*h6);

%duopoly, IN=1
w7=(g5d(1)+(g5d(2)+log(2))-g5d(7))/g5d(4);
W7=exp(w7);
h7=[(1/g5d(4))*W7;(1/g5d(4))*W7;0;-w7*(1/g5d(4))*W7;zeros(2,1);-(1/g5d(4))*W7;0;0];
sw7=sqrt(h7'*V5d*h7);

%triopoly, IN=0 & SCO=0
w9=(g5d(1)+(g5d(3)+log(3)))/g5d(4);
W9=exp(w9);
h9=[(1/g5d(4))*W9;0;(1/g5d(4))*W9;-w9*(1/g5d(4))*W9;zeros(5,1)];
sw9=sqrt(h9'*V5d*h9);

%triopoly, IN=0 & SCO=1 (not shown b/c SCO duopoly non-existent in 1860)
w10=(g5d(1)+(g5d(3)+log(3))-g5d(8))/g5d(4);
W10=exp(w10);
h10=[(1/g5d(4))*W10;0;(1/g5d(4))*W10;-w10*(1/g5d(4))*W10;zeros(3,1);-(1/g5d(4))*W10;0];
sw10=sqrt(h10'*V5d*h10);

%triopoly, IN=1
w11=(g5d(1)+(g5d(3)+log(3))-g5d(7))/g5d(4);
W11=exp(w11);
h11=[(1/g5d(4))*W11;0;(1/g5d(4))*W11;-w11*(1/g5d(4))*W11;zeros(2,1);-(1/g5d(4))*W11;0;0];
sw11=sqrt(h11'*V5d*h11);

W5d=[W1;W2;W3;W5;W7;W9;W11];
sw5d=[sw1;sw2;sw3;sw5;sw7;sw9;sw11];

disp('Implied entry thresholds for 1860 Triopoly-Plus: Table 5d')
disp('   Estimate     s.e.')
disp([W5d sw5d])

%CONSTRUCTING THRESHOLD RATIOS & STD ERRORS
z15d=(g5d(2)+log(2))/g5d(4);
Z15d=exp(z15d);
k15d=[0;(1/g5d(4))*Z15d;0;-z15d*(1/g5d(4))*Z15d;zeros(5,1)];
sk15d=sqrt(k15d'*V5d*k15d);

Z25d=.5*Z15d;
sk25d=.5*sk15d;
pk25d=2*(1-normcdf((Z25d-1)/sk25d));

z35d=(g5d(3)+log(3)-g5d(2)-log(2))/g5d(4);
Z35d=exp(z35d);
k35d=[0;-(1/g5d(4))*Z35d;(1/g5d(4))*Z35d;-z35d*(1/g5d(4))*Z35d;zeros(5,1)];
sk35d=sqrt(k35d'*V5d*k35d);

Z45d=(2/3)*Z35d;
sk45d=(2/3)*sk35d;
pk45d=2*(1-normcdf((Z45d-1)/sk45d));

disp('Duopoly-vs-Monopoly threshold test (Per-firm pop ratio)')
disp('    Ratio     s.e.      p-value')
disp([Z25d sk25d pk25d])
disp('Triopoly-vs-Duopoly threshold test (Per-firm pop ratio)')
disp('    Ratio     s.e.      p-value')
disp([Z45d sk45d pk45d])

%Note: Footnote 49 mis-states p-value for this duopoly-vs-monopoly hypothesis-test, 
%  specifically tests null of zero instead of correct null of one ... correct 
%  p-value under triopoly-plus is p = 0.14


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   POOLED CROSS-SECTIONS, 1854 & 1860: TABLE 6   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%
% DUOPOLY-PLUS: TABLE 6A %
%%%%%%%%%%%%%%%%%%%%%%%%%%

%opening guess at parameters
g06a=[10.912;.725;1.355;1.843;-.187;.010;.853;-1.803;-.803;-.394];

options=optimset('MaxFunEvals',100000,'MaxIter',100000);

g6a=fminsearch('JMCBchabotmoul6a',g06a,options);%no-bank, monopoly-bank, duopoly, triopoly-plu

L06a=JMCBchabotmoul6a(g6a);%obj func value at optimal parameters
L0=L06a;

%CONSTRUCTING INFORMATION MATRIX
h0=g6a;
sg6a=size(g6a,1);
Info=zeros(sg6a,sg6a);
for i=1:sg6a;
    for j=1:sg6a;
        h1=h0;
        h2=h0;
        ep=.00001;
        h1(i)=h0(i)+ep;
        h2(j)=h0(j)+ep;
        h3=h2;
        h3(i)=h2(i)+ep;
        L1=JMCBchabotmoul6a(h1);
        L2=JMCBchabotmoul6a(h2);
        L3=JMCBchabotmoul6a(h3);
        Info(i,j)=((L3-L2)/ep-(L1-L0)/ep)/ep;
    end;
end;

%CONSTRUCTING COVARIANCE MATRIX
V6a=inv(Info);
se6a=sqrt(diag(V6a));

disp('Pooled cross sections with Duopoly-Plus: Table 6a')
disp('   Estimate     s.e.')
disp([g6a se6a])
disp('/log-lik/')
disp(L06a)

%CONSTRUCTING ENTRY THRESHOLDS & STD ERRORS (delta method)

%monopoly, IN=0 & SCO=0
w1=(g6a(1))/g6a(3);
W1=exp(w1);
h1=[1/g6a(3)*W1;0;-w1*(1/g6a(3))*W1;zeros(7,1)];
sw1=sqrt(h1'*V6a*h1);

%monopoly, IN=0 & SCO=1
w2=(g6a(1)-g6a(9))/g6a(3);
W2=exp(w2);
h2=[1/g6a(3)*W2;0;-w2*(1/g6a(3))*W2;zeros(5,1);-(1/g6a(3))*W2;0];
sw2=sqrt(h2'*V6a*h2);

%monopoly, IN=1 in 1854
w3=(g6a(1)-g6a(7))/g6a(3);
W3=exp(w3);
h3=[1/g6a(3)*W3;0;-w3*(1/g6a(3))*W3;zeros(3,1);-(1/g6a(3))*W3;0;0;0];
sw3=sqrt(h3'*V6a*h3);

%monopoly, IN=1 in 1860
w4=(g6a(1)-g6a(7)-g6a(8))/g6a(3);
W4=exp(w4);
h4=[1/g6a(3)*W4;0;-w4*(1/g6a(3))*W4;zeros(3,1);-(1/g6a(3))*W4;-(1/g6a(3))*W4;0;0];
sw4=sqrt(h4'*V6a*h4);

%duopoly, IN=0 & SCO=0
w5=(g6a(1)+(g6a(2)+log(2)))/g6a(3);
W5=exp(w5);
h5=[1/g6a(3)*W5;1/g6a(3)*W5;-w5*(1/g6a(3))*W5;zeros(7,1)];
sw5=sqrt(h5'*V6a*h5);

%duopoly, IN=0 & SCO=1 
w6=(g6a(1)+(g6a(2)+log(2))-g6a(9))/g6a(3);
W6=exp(w6);
h6=[1/g6a(3)*W6;1/g6a(3)*W6;-w6*(1/g6a(3))*W6;zeros(5,1);-(1/g6a(3))*W6;0];
sw6=sqrt(h6'*V6a*h6);

%duopoly, IN=1 in 1854
w7=(g6a(1)+(g6a(2)+log(2))-g6a(7))/g6a(3);
W7=exp(w7);
h7=[1/g6a(3)*W7;1/g6a(3)*W7;-w7*(1/g6a(3))*W7;0;0;0;-(1/g6a(3))*W7;0;0;0];
sw7=sqrt(h7'*V6a*h7);

%duopoly, IN=1 in 1860
w8=(g6a(1)+(g6a(2)+log(2))-g6a(7)-g6a(8))/g6a(3);
W8=exp(w8);
h8=[1/g6a(3)*W8;1/g6a(3)*W8;-w8*(1/g6a(3))*W8;0;0;0;-(1/g6a(3))*W8;-(1/g6a(3))*W8;0;0];
sw8=sqrt(h8'*V6a*h8);

W6a=[W1;W2;W3;W4;W5;W7;W8];
sw6a=[sw1;sw2;sw3;sw4;sw5;sw7;sw8];

disp('Implied entry thresholds for Pooled Duopoly-Plus: Table 6a')
disp('   Estimate     s.e.')
disp([W6a sw6a])

%CONSTRUCTING THRESHOLD RATIOS & STD ERRORS
z16a=(g6a(2)+log(2))/g6a(3);
Z16a=exp(z16a);
k16a=[0;(1/g6a(3))*Z16a;-z16a*(1/g6a(3))*Z16a;zeros(7,1)];
sk16a=sqrt(k16a'*V6a*k16a);

Z26a=.5*Z16a;
sk26a=.5*sk16a;

pk26a=2*(1-normcdf((Z26a-1)/sk26a));

disp('Duopoly-vs-Monopoly threshold test (Per-firm pop ratio)')
disp('    Ratio     s.e.      p-value')
disp([Z26a sk26a pk26a])


%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TRIOPOLY-PLUS: TABLE 6B %
%%%%%%%%%%%%%%%%%%%%%%%%%%%

%opening guess at parameters
g06b=[10.884;.678;1.175;1.354;1.764;-.152;-.005;.877;-1.722;-.768;-.419];

options=optimset('MaxFunEvals',100000,'MaxIter',100000);

g6b=fminsearch('JMCBchabotmoul6b',g06b,options);%no-bank, monopoly-bank, duopoly-plus

L06b=JMCBchabotmoul6b(g6b);%obj func value at optimal parameters
L0=L06b;

%CONSTRUCTING INFORMATION MATRIX
h0=g6b;
sg6b=size(g6b,1);
Info=zeros(sg6b,sg6b);
for i=1:sg6b;
    for j=1:sg6b;
        h1=h0;
        h2=h0;
        ep=.00001;
        h1(i)=h0(i)+ep;
        h2(j)=h0(j)+ep;
        h3=h2;
        h3(i)=h2(i)+ep;
        L1=JMCBchabotmoul6b(h1);
        L2=JMCBchabotmoul6b(h2);
        L3=JMCBchabotmoul6b(h3);
        Info(i,j)=((L3-L2)/ep-(L1-L0)/ep)/ep;
    end;
end;

%CONSTRUCTING COVARIANCE MATRIX
V6b=inv(Info);
se6b=sqrt(diag(V6b));

disp('Pooled cross sections with Triopoly-Plus: Table 6b')
disp('   Estimate     s.e.')
disp([g6b se6b])
disp('/log-lik/')
disp(L06b)

%TESTING NULL THAT MU_DUO = MU_TRI
k6b=[0;-1;1;zeros(8,1)];
J6b=(k6b'*g6b)/sqrt(k6b'*V6b*k6b);
p6b=2*(1-normcdf(J6b));
disp('p-stat on mu_duo=mu_tri')
disp(p6b)

%CONSTRUCTING ENTRY THRESHOLDS & STD ERRORS (delta method)

%monopoly, IN=0 & SCO=0
w1=(g6b(1))/g6b(4);
W1=exp(w1);
h1=[1/g6b(4)*W1;0;0;-w1*(1/g6b(4))*W1;zeros(7,1)];
sw1=sqrt(h1'*V6b*h1);

%monopoly, IN=0 & SCO=1
w2=(g6b(1)-g6b(10))/g6b(4);
W2=exp(w2);
h2=[1/g6b(4)*W2;0;0;-w2*(1/g6b(4))*W2;zeros(5,1);-(1/g6b(4))*W2;0];
sw2=sqrt(h2'*V6b*h2);

%monopoly, IN=1 in 1854
w3=(g6b(1)-g6b(8))/g6b(4);
W3=exp(w3);
h3=[1/g6b(4)*W3;0;0;-w3*(1/g6b(4))*W3;zeros(3,1);-(1/g6b(4))*W3;0;0;0];
sw3=sqrt(h3'*V6b*h3);

%monopoly, IN=1 in 1860
w4=(g6b(1)-g6b(8)-g6b(9))/g6b(4);
W4=exp(w4);
h4=[1/g6b(4)*W4;0;0;-w4*(1/g6b(4))*W4;zeros(3,1);-(1/g6b(4))*W4;-(1/g6b(4))*W4;0;0];
sw4=sqrt(h4'*V6b*h4);

%duopoly, IN=0 & SCO=0
w5=(g6b(1)+(g6b(2)+log(2)))/g6b(4);
W5=exp(w5);
h5=[1/g6b(4)*W5;1/g6b(4)*W5;0;-w5*(1/g6b(4))*W5;zeros(7,1)];
sw5=sqrt(h5'*V6b*h5);

%duopoly, IN=0 & SCO=1 (not shown)
w6=(g6b(1)+(g6b(2)+log(2))-g6b(10))/g6b(4);
W6=exp(w6);
h6=[1/g6b(4)*W6;1/g6b(4)*W6;0;-w6*(1/g6b(4))*W6;zeros(5,1);-(1/g6b(4))*W6;0];
sw6=sqrt(h6'*V6b*h6);

%duopoly, IN=1 in 1854
w7=(g6b(1)+(g6b(2)+log(2))-g6b(8))/g6b(4);
W7=exp(w7);
h7=[1/g6b(4)*W7;1/g6b(4)*W7;0;-w7*(1/g6b(4))*W7;0;0;0;-(1/g6b(4))*W7;0;0;0];
sw7=sqrt(h7'*V6b*h7);

%duopoly, IN=1 in 1860
w8=(g6b(1)+(g6b(2)+log(2))-g6b(8)-g6b(9))/g6b(4);
W8=exp(w8);
h8=[1/g6b(4)*W8;1/g6b(4)*W8;0;-w8*(1/g6b(4))*W8;0;0;0;-(1/g6b(4))*W8;-(1/g6b(4))*W8;0;0];
sw8=sqrt(h8'*V6b*h8);

%triopoly, IN=0 & SCO=0
w9=(g6b(1)+(g6b(3)+log(3)))/g6b(4);
W9=exp(w9);
h9=[1/g6b(4)*W9;0;1/g6b(4)*W9;-w9*(1/g6b(4))*W9;zeros(7,1)];
sw9=sqrt(h9'*V6b*h9);

%triopoly, IN=0 & SCO=1 (not shown)
w10=(g6b(1)+(g6b(3)+log(3))-g6b(10))/g6b(4);
W10=exp(w10);
h10=[1/g6b(4)*W10;0;1/g6b(4)*W10;-w10*(1/g6b(4))*W10;zeros(5,1);-(1/g6b(4))*W10;0];
sw10=sqrt(h10'*V6b*h10);

%triopoly, IN=1 in 1854
w11=(g6b(1)+(g6b(3)+log(3))-g6b(8))/g6b(4);
W11=exp(w11);
h11=[1/g6b(4)*W11;0;1/g6b(4)*W11;-w11*(1/g6b(4))*W11;0;0;0;-(1/g6b(4))*W11;0;0;0];
sw11=sqrt(h11'*V6b*h11);

%triopoly, IN=1 in 1860
w12=(g6b(1)+(g6b(3)+log(3))-g6b(8)-g6b(9))/g6b(4);
W12=exp(w12);
h12=[1/g6b(4)*W12;0;1/g6b(4)*W12;-w12*(1/g6b(4))*W12;0;0;0;-(1/g6b(4))*W12;-(1/g6b(4))*W12;0;0];
sw12=sqrt(h12'*V6b*h12);

W6a=[W1;W2;W3;W4;W5;W7;W8;W9;W11;W12];
sw6a=[sw1;sw2;sw3;sw4;sw5;sw7;sw8;sw9;sw11;sw12];

disp('Implied entry thresholds for Pooled Triopoly-Plus: Table 6b')
disp('   Estimate     s.e.')
disp([W6a sw6a])

%CONSTRUCTING THRESHOLD RATIOS & STD ERRORS
z16b=(g6b(2)+log(2))/g6b(4);
Z16b=exp(z16b);
k16b=[0;(1/g6b(4))*Z16b;0;-z16b*(1/g6b(4))*Z16b;zeros(7,1)];
sk16b=sqrt(k16b'*V6b*k16b);

Z26b=.5*Z16b;
sk26b=.5*sk16b;
pk26b=2*(1-normcdf((Z26b-1)/sk26b));

z36b=(g6b(3)+log(3)-g6b(2)-log(2))/g6b(4);
Z36b=exp(z36b);
k36b=[0;-(1/g6b(4))*Z36b;(1/g6b(4))*Z36b;-z36b*(1/g6b(4))*Z36b;zeros(7,1)];
sk36b=sqrt(k36b'*V6b*k36b);

Z46b=(2/3)*Z36b;
sk46b=(2/3)*sk36b;
pk46b=2*(1-normcdf((Z46b-1)/sk46b));

disp('Duopoly-vs-Monopoly threshold test (Per-firm pop ratio)')
disp('    Ratio     s.e.      p-value')
disp([Z26b sk26b pk26b])
disp('Triopoly-vs-Duopoly threshold test (Per-firm pop ratio)')
disp('    Ratio     s.e.      p-value')
disp([Z46b sk46b pk46b])


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1860 SAMPLE WITH '57 CLOSURES: TABLE 7 %
%    - IOWA OMITTED                      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%ELIMINATING OBSERVATIONS FROM SAMPLE
%dropping Iowa from 1860 sample (banking illegal until 1858)
f=find(D2(:,23)==0);%identifies non-Iowa states
D3=D2(f,:);
sd3=size(D3,1);

Dro607=Dro601(f);
SCO60=SCO60(f);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DUOPOLY-PLUS BASELINE: TABLE 7a %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%opening guess at parameters
g07a=[5.215;.298;.673;.012;.008;-.627;-.611;-.588];

g7a=fminsearch('JMCBchabotmoul7a',g07a);%no-bank, monopoly-bank, duopoly-plus

L07a=JMCBchabotmoul7a(g7a);%obj func value at optimal parameters
L0=L07a;

%CONSTRUCTING INFORMATION MATRIX
h0=g7a;
sg7a=size(g7a,1);
Info=zeros(sg7a,sg7a);
for i=1:sg7a;
    for j=1:sg7a;
        h1=h0;
        h2=h0;
        ep=.00001;
        h1(i)=h0(i)+ep;
        h2(j)=h0(j)+ep;
        h3=h2;
        h3(i)=h2(i)+ep;
        L1=JMCBchabotmoul7a(h1);
        L2=JMCBchabotmoul7a(h2);
        L3=JMCBchabotmoul7a(h3);
        Info(i,j)=((L3-L2)/ep-(L1-L0)/ep)/ep;
    end;
end;

%CONSTRUCTING COVARIANCE MATRIX
V7a=inv(Info);
se7a=sqrt(diag(V7a));

disp('1860 cross section with Duopoly-Plus: Table 7a')
disp('   Estimate     s.e.')
disp([g7a se7a])
disp('/log-lik/')
disp(L07a)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TRIOPOLY-PLUS BASELINE: TABLE 7b %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%opening guess at parameters
g07b=[5.201;.300;.572;.671;.020;.002;-.658;-.591;-.585];

g7b=fminsearch('JMCBchabotmoul7b',g07b);%no-bank, monopoly-bank, duopoly-plus

L07b=JMCBchabotmoul7b(g7b);%obj func value at optimal parameters
L0=L07b;

%CONSTRUCTING INFORMATION MATRIX
h0=g7b;
sg7b=size(g7b,1);
Info=zeros(sg7b,sg7b);
for i=1:sg7b;
    for j=1:sg7b;
        h1=h0;
        h2=h0;
        ep=.00001;
        h1(i)=h0(i)+ep;
        h2(j)=h0(j)+ep;
        h3=h2;
        h3(i)=h2(i)+ep;
        L1=JMCBchabotmoul7b(h1);
        L2=JMCBchabotmoul7b(h2);
        L3=JMCBchabotmoul7b(h3);
        Info(i,j)=((L3-L2)/ep-(L1-L0)/ep)/ep;
    end;
end;

%CONSTRUCTING COVARIANCE MATRIX
V7b=inv(Info);
se7b=sqrt(diag(V7b));

disp('1860 cross section with Triopoly-Plus: Table 7b')
disp('   Estimate     s.e.')
disp([g7b se7b])
disp('/log-lik/')
disp(L07b)

%TESTING NULL THAT MU_DUO = MU_TRI
k7b=[0;-1;1;zeros(6,1)];
J7b=(k7b'*g7b)/sqrt(k7b'*V7b*k7b);
p7b=2*(1-normcdf(J7b));
disp('p-stat on mu_duo=mu_tri')
disp(p7b)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TRIOPOLY-PLUS WITH '57 BANKS: TABLE 7c %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%opening guess at parameters
g07c=[3.202;.556;.964;.385;.087;-.020;-.730;-.797;-.362;1.025];

g7c=fminsearch('JMCBchabotmoul7c',g07c);%no-bank, monopoly-bank, duopoly-plus

L07c=JMCBchabotmoul7c(g7c);%obj func value at optimal parameters
L0=L07c;

%CONSTRUCTING INFORMATION MATRIX
h0=g7c;
sg7c=size(g7c,1);
Info=zeros(sg7c,sg7c);
for i=1:sg7c;
    for j=1:sg7c;
        h1=h0;
        h2=h0;
        ep=.00001;
        h1(i)=h0(i)+ep;
        h2(j)=h0(j)+ep;
        h3=h2;
        h3(i)=h2(i)+ep;
        L1=JMCBchabotmoul7c(h1);
        L2=JMCBchabotmoul7c(h2);
        L3=JMCBchabotmoul7c(h3);
        Info(i,j)=((L3-L2)/ep-(L1-L0)/ep)/ep;
    end;
end;

%CONSTRUCTING COVARIANCE MATRIX
V7c=inv(Info);
se7c=sqrt(diag(V7c));

disp('1860 cross section with Triopoly-Plus: Table 7c')
disp('   Estimate     s.e.')
disp([g7c se7c])
disp('/log-lik/')
disp(L07c)

%TESTING NULL THAT MU_DUO = MU_TRI
k7c=[0;-1;1;zeros(7,1)];
J7c=(k7c'*g7c)/sqrt(k7c'*V7c*k7c);
p7c=2*(1-normcdf(J7c));
disp('p-stat on mu_duo=mu_tri')
disp(p7c)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TRIOPOLY-PLUS WITH '57 BANKS & CLOSURES: TABLE 7d %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%opening guess at parameters
g07d=[2.689;.575;1.004;.309;.074;-.005;-.744;-.689;-.344;1.215;-.883];

g7d=fminsearch('JMCBchabotmoul7d',g07d);%no-bank, monopoly-bank, duopoly-plus

L07d=JMCBchabotmoul7d(g7d);%obj func value at optimal parameters
L0=L07d;

%CONSTRUCTING INFORMATION MATRIX
h0=g7d;
sg7d=size(g7d,1);
Info=zeros(sg7d,sg7d);
for i=1:sg7d;
    for j=1:sg7d;
        h1=h0;
        h2=h0;
        ep=.00001;
        h1(i)=h0(i)+ep;
        h2(j)=h0(j)+ep;
        h3=h2;
        h3(i)=h2(i)+ep;
        L1=JMCBchabotmoul7d(h1);
        L2=JMCBchabotmoul7d(h2);
        L3=JMCBchabotmoul7d(h3);
        Info(i,j)=((L3-L2)/ep-(L1-L0)/ep)/ep;
    end;
end;

%CONSTRUCTING COVARIANCE MATRIX
V7d=inv(Info);
se7d=sqrt(diag(V7d));

disp('1860 cross section with Triopoly-Plus: Table 7d')
disp('   Estimate     s.e.')
disp([g7d se7d])
disp('/log-lik/')
disp(L07d)

%TESTING NULL THAT MU_DUO = MU_TRI
k7d=[0;-1;1;zeros(8,1)];
J7d=(k7d'*g7d)/sqrt(k7d'*V7d*k7d);
p7d=2*(1-normcdf(J7d));
disp('p-stat on mu_duo=mu_tri')
disp(p7d)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TRIOPOLY-PLUS WITH '57 BANKS & CLOSURES BY INDIANA-NESS: TABLE 7e %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%opening guess at parameters
g07e=[2.718;.577;1.010;.312;.075;-.006;-.743;-.674;-.339;1.214;-.711;-.219];

g7e=fminsearch('JMCBchabotmoul7e',g07e);%no-bank, monopoly-bank, duopoly-plus

L07e=JMCBchabotmoul7e(g7e);%obj func value at optimal parameters
L0=L07e;

%CONSTRUCTING INFORMATION MATRIX
h0=g7e;
sg7e=size(g7e,1);
Info=zeros(sg7e,sg7e);
for i=1:sg7e;
    for j=1:sg7e;
        h1=h0;
        h2=h0;
        ep=.00001;
        h1(i)=h0(i)+ep;
        h2(j)=h0(j)+ep;
        h3=h2;
        h3(i)=h2(i)+ep;
        L1=JMCBchabotmoul7e(h1);
        L2=JMCBchabotmoul7e(h2);
        L3=JMCBchabotmoul7e(h3);
        Info(i,j)=((L3-L2)/ep-(L1-L0)/ep)/ep;
    end;
end;

%CONSTRUCTING COVARIANCE MATRIX
V7e=inv(Info);
se7e=sqrt(diag(V7e));

disp('1860 cross section with Triopoly-Plus: Table 7e')
disp('   Estimate     s.e.')
disp([g7e se7e])
disp('/log-lik/')
disp(L07e)

%TESTING NULL THAT MU_DUO = MU_TRI
k7e=[0;-1;1;zeros(9,1)];
J7e=(k7e'*g7e)/sqrt(k7e'*V7e*k7e);
p7e=2*(1-normcdf(J7e));
disp('p-stat on mu_duo=mu_tri')
disp(p7e)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1860 SAMPLE WITH '50s FAILURE RATES: TABLE 8 %
%    - IOWA OMITTED                            %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%now adding statewide bank failure rates ('54, '57, average)
FR54_0=[0/49;3/65;46/87;8/33;4/23;0;0/5];
FR57_0=[1/55;4/62;9/50;8/48;3/60;0;0/6];
FRAvg_0=[(0+1)/(49+55);(3+4)/(65+62);(46+9)/(87+50);(8+8)/(33+48);(4+3)/(23+60);0;(0+0)/(5+6)];
FR54=D3(:,18:24)*FR54_0;
FR57=D3(:,18:24)*FR57_0;
FRAvg=D3(:,18:24)*FRAvg_0;

D4=[D3 FR54 FR57 FRAvg];


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TRIOPOLY-PLUS BASELINE: TABLE 8a %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%opening guess at parameters
g08a=[5.201;.300;.572;.671;.020;.002;-.591;-.585;-.658];

g8a=fminsearch('JMCBchabotmoul8a',g08a);%no-bank, monopoly-bank, duopoly-plus

L08a=JMCBchabotmoul8a(g8a);%obj func value at optimal parameters
L0=L08a;

%CONSTRUCTING INFORMATION MATRIX
h0=g8a;
sg8a=size(g8a,1);
Info=zeros(sg8a,sg8a);
for i=1:sg8a;
    for j=1:sg8a;
        h1=h0;
        h2=h0;
        ep=.00001;
        h1(i)=h0(i)+ep;
        h2(j)=h0(j)+ep;
        h3=h2;
        h3(i)=h2(i)+ep;
        L1=JMCBchabotmoul8a(h1);
        L2=JMCBchabotmoul8a(h2);
        L3=JMCBchabotmoul8a(h3);
        Info(i,j)=((L3-L2)/ep-(L1-L0)/ep)/ep;
    end;
end;

%CONSTRUCTING COVARIANCE MATRIX
V8a=inv(Info);
se8a=sqrt(diag(V8a));

disp('1860 cross section with Triopoly-Plus: Table 8a')
disp('   Estimate     s.e.')
disp([g8a se8a])
disp('/log-lik/')
disp(L08a)

%TESTING NULL THAT MU_DUO = MU_TRI
k8a=[0;-1;1;zeros(6,1)];
J8a=(k8a'*g8a)/sqrt(k8a'*V8a*k8a);
p8a=2*(1-normcdf(J8a));
disp('p-stat on mu_duo=mu_tri')
disp(p8a)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TRIOPOLY-PLUS WITHOUT INDIANA: TABLE 8b %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%opening guess at parameters
g08b=[5.127;.264;.507;.639;.016;.002;-.428;-.678];

g8b=fminsearch('JMCBchabotmoul8b',g08b);%no-bank, monopoly-bank, duopoly-plus

L08b=JMCBchabotmoul8b(g8b);%obj func value at optimal parameters
L0=L08b;

%CONSTRUCTING INFORMATION MATRIX
h0=g8b;
sg8b=size(g8b,1);
Info=zeros(sg8b,sg8b);
for i=1:sg8b;
    for j=1:sg8b;
        h1=h0;
        h2=h0;
        ep=.00001;
        h1(i)=h0(i)+ep;
        h2(j)=h0(j)+ep;
        h3=h2;
        h3(i)=h2(i)+ep;
        L1=JMCBchabotmoul8b(h1);
        L2=JMCBchabotmoul8b(h2);
        L3=JMCBchabotmoul8b(h3);
        Info(i,j)=((L3-L2)/ep-(L1-L0)/ep)/ep;
    end;
end;

%CONSTRUCTING COVARIANCE MATRIX
V8b=inv(Info);
se8b=sqrt(diag(V8b));

disp('1860 cross section with Triopoly-Plus: Table 8b')
disp('   Estimate     s.e.')
disp([g8b se8b])
disp('/log-lik/')
disp(L08b)

%TESTING NULL THAT MU_DUO = MU_TRI
k8b=[0;-1;1;zeros(5,1)];
J8b=(k8b'*g8b)/sqrt(k8b'*V8b*k8b);
p8b=2*(1-normcdf(J8b));
disp('p-stat on mu_duo=mu_tri')
disp(p8b)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TRIOPOLY-PLUS WITH FAILURE RATE: TABLE 8c %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%opening guess at parameters
g08c=[5.144;.277;.531;.650;.034;.001;-.638;-1.000;-.676];

g8c=fminsearch('JMCBchabotmoul8c',g08c);%no-bank, monopoly-bank, duopoly-plus

L08c=JMCBchabotmoul8c(g8c);%obj func value at optimal parameters
L0=L08c;

%CONSTRUCTING INFORMATION MATRIX
h0=g8c;
sg8c=size(g8c,1);
Info=zeros(sg8c,sg8c);
for i=1:sg8c;
    for j=1:sg8c;
        h1=h0;
        h2=h0;
        ep=.00001;
        h1(i)=h0(i)+ep;
        h2(j)=h0(j)+ep;
        h3=h2;
        h3(i)=h2(i)+ep;
        L1=JMCBchabotmoul8c(h1);
        L2=JMCBchabotmoul8c(h2);
        L3=JMCBchabotmoul8c(h3);
        Info(i,j)=((L3-L2)/ep-(L1-L0)/ep)/ep;
    end;
end;

%CONSTRUCTING COVARIANCE MATRIX
V8c=inv(Info);
se8c=sqrt(diag(V8c));

disp('1860 cross section with Triopoly-Plus: Table 8c')
disp('   Estimate     s.e.')
disp([g8c se8c])
disp('/log-lik/')
disp(L08c)

%TESTING NULL THAT MU_DUO = MU_TRI
k8c=[0;-1;1;zeros(6,1)];
J8c=(k8c'*g8c)/sqrt(k8c'*V8c*k8c);
p8c=2*(1-normcdf(J8c));
disp('p-stat on mu_duo=mu_tri')
disp(p8c)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% TRIOPOLY-PLUS WITH FAILURE RATE BY INDIANA-NESS: TABLE 8d %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%opening guess at parameters
g08d=[5.727;.325;.614;.700;-.063;.004;.060;4.919;-5.024;-.625];

g8d=fminsearch('JMCBchabotmoul8d',g08d);%no-bank, monopoly-bank, duopoly-plus

L08d=JMCBchabotmoul8d(g8d);%obj func value at optimal parameters
L0=L08d;

%CONSTRUCTING INFORMATION MATRIX
h0=g8d;
sg8d=size(g8d,1);
Info=zeros(sg8d,sg8d);
for i=1:sg8d;
    for j=1:sg8d;
        h1=h0;
        h2=h0;
        ep=.00001;
        h1(i)=h0(i)+ep;
        h2(j)=h0(j)+ep;
        h3=h2;
        h3(i)=h2(i)+ep;
        L1=JMCBchabotmoul8d(h1);
        L2=JMCBchabotmoul8d(h2);
        L3=JMCBchabotmoul8d(h3);
        Info(i,j)=((L3-L2)/ep-(L1-L0)/ep)/ep;
    end;
end;

%CONSTRUCTING COVARIANCE MATRIX
V8d=inv(Info);
se8d=sqrt(diag(V8d));

disp('1860 cross section with Triopoly-Plus: Table 8d')
disp('   Estimate     s.e.')
disp([g8d se8d])
disp('/log-lik/')
disp(L08d)

%TESTING NULL THAT MU_DUO = MU_TRI
k8d=[0;-1;1;zeros(7,1)];
J8d=(k8d'*g8d)/sqrt(k8d'*V8d*k8d);
p8d=2*(1-normcdf(J8d));
disp('p-stat on mu_duo=mu_tri')
disp(p8d)





